@@ -4,7 +4,7 @@ package WebService::Rollbar::Notifier;
 use strict;
 use warnings;
 
-our $VERSION = '1.002005'; # VERSION
+our $VERSION = '1.002006'; # VERSION
 
 use Carp;
 use Scalar::Util qw/blessed/;
@@ -33,7 +33,7 @@ sub _parse_message_param {
     my $message = shift;
 
     if (ref($message) eq 'ARRAY') {
-        return ($message->[0], $message->[1]);
+        return ($message->[0], $message->[1]||{});
     } else {
         return ($message, {} );
     }
@@ -316,7 +316,7 @@ The name of the framework your code uses
         }
     );
 
-B<Optional>. B<By default> is not specifed.
+B<Optional>. B<By default> is not specified.
 Takes a hashref, which is used as "server" part of every Rollbar request made
 by this notifier instance. See L<https://rollbar.com/docs/api/items_post/> for
 detailed description of supported fields.
@@ -519,7 +519,7 @@ L<https://rollbar.com/docs/api/items_post/>)
 
 =head3 $additional_parameters
 
-B<Optional>. Seel L</$additional_parameters> for details. Note that for
+B<Optional>. See L</$additional_parameters> for details. Note that for
 exceptions default level is "error".
 
 =for html  </div></div>
